@@ -12,15 +12,15 @@
 # implied. See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Default allowed headers
 import copy
 import logging
 
+import debtcollector
 from oslo_config import cfg
 from oslo_middleware import base
 import six
 import webob.exc
-import webob.response
+
 
 LOG = logging.getLogger(__name__)
 
@@ -98,11 +98,6 @@ class InvalidOriginError(Exception):
             'CORS request from origin \'%s\' not permitted.' % origin)
 
 
-class _NoContentTypeResponse(webob.response.Response):
-
-    default_content_type = None  # prevents webob assigning content type
-
-
 class CORS(base.ConfigurableMiddleware):
     """CORS Middleware.
 
@@ -203,6 +198,11 @@ class CORS(base.ConfigurableMiddleware):
         # prefixed with 'cors.'
         for section in self.oslo_conf.list_all_sections():
             if section.startswith('cors.'):
+                debtcollector.deprecate('Multiple configuration blocks are '
+                                        'deprecated and will be removed in '
+                                        'future versions. Please consolidate '
+                                        'your configuration in the [cors] '
+                                        'configuration block.')
                 # Register with the preconstructed defaults
                 self.oslo_conf.register_opts(subgroup_opts, section)
                 self.add_origin(**self.oslo_conf[section])
@@ -224,6 +224,9 @@ class CORS(base.ConfigurableMiddleware):
         # NOTE(dims): Support older code that still passes in
         # a string for allowed_origin instead of a list
         if isinstance(allowed_origin, six.string_types):
+            # TODO(krotscheck): https://review.openstack.org/#/c/312687/
+            LOG.warn('DEPRECATED: The `allowed_origin` keyword argument in '
+                     '`add_origin()` should be a list, found String.')
             allowed_origin = [allowed_origin]
 
         if allowed_origin:
@@ -325,7 +328,7 @@ class CORS(base.ConfigurableMiddleware):
         # underlying middleware's response content needs to be persisted.
         # Otherwise, create a new response.
         if 200 > response.status_code or response.status_code >= 300:
-            response = _NoContentTypeResponse(status=webob.exc.HTTPOk.code)
+            response = base.NoContentTypeResponse(status=webob.exc.HTTPOk.code)
 
         # Does the request have an origin header? (Section 6.2.1)
         if 'Origin' not in request.headers:
